powered by
Return a data.frame of filenames for the images
get_image_filenames_df( ids = get_ids(), modalities = all_modalities(), visits = c(1, 2), long = TRUE, warn = TRUE, outdir = NULL )get_image_filenames_matrix(...)get_image_filenames_list(...)get_image_filenames_list_by_visit(...)get_image_filenames_list_by_subject(...)
get_image_filenames_matrix(...)
get_image_filenames_list(...)
get_image_filenames_list_by_visit(...)
get_image_filenames_list_by_subject(...)
ID to return
vector of image modalities within c("FLAIR", "MPRAGE", "T2w", "fMRI", "DTI") to return
c("FLAIR", "MPRAGE", "T2w", "fMRI", "DTI")
Vector of scan indices to return (1 or 2 or both)
if TRUE, each row is a subject, visit, modality pair
TRUE
if TRUE, warnings will be produced when packages are not installed
output directory for files to download. It will default to the directory of the corresponding package for the data.
arguments passed to get_image_filenames_df
get_image_filenames_df
Data.frame of filenames
# NOT RUN { get_image_filenames_df() get_image_filenames_matrix() get_image_filenames_list() get_image_filenames_list_by_visit() get_image_filenames_list_by_subject() # }
Run the code above in your browser using DataLab