Learn R Programming

kirby21.base (version 1.7.3)

download_kirby21_data: Download Kirby21 Imaging Data

Description

This function allows users to download specific modalities for Kirby21 data sets. This allows this package to be on CRAN

Usage

download_kirby21_data(
  modality = kirby21.base::all_modalities(),
  progress = TRUE,
  force = FALSE,
  outdir = NULL
)

Arguments

modality

modality of images that are to be downloaded. You must have the package downloaded for that modality.

progress

Should verbose messages be printed when downloading the data

force

If the package of that modality is not installed stop. If force = FALSE, then this will download the data but not really install the package.

outdir

output directory for files to download. It will default to the directory of the corresponding package for the data.

Value

A logical indicating the data is there.

Examples

Run this code
# NOT RUN {
on_cran = !identical(Sys.getenv("NOT_CRAN"), "true")
on_ci <- nzchar(Sys.getenv("CI"))
local_run = grepl("musch", tolower(Sys.info()[["user"]]))
run_example = !on_cran || on_ci || local_run
if (run_example) {
outdir = tempdir()
res = download_kirby21_data("SURVEY", outdir = outdir)
}
# }

Run the code above in your browser using DataLab